<?php
/**
 * Gutenix Theme Customizer
 *
 * @package Gutenix
 */

/**
 * Retrieve a holder for Customizer options.
 *
 * @since  1.0.0
 * @return array
 */
function gutenix_get_customizer_options() {
	return apply_filters( 'gutenix_get_customizer_options', array(
		'prefix'        => 'gutenix',
		'path'          => get_theme_file_path( 'inc/modules/customizer/' ),
		'capability'    => 'edit_theme_options',
		'type'          => 'theme_mod',
		'fonts_manager' => gutenix_theme()->fonts_manager,
		'options'       => array(

			/** `Site Identity` section */
			'show_tagline' => array(
				'title'    => esc_html__( 'Show tagline after logo', 'gutenix' ),
				'section'  => 'title_tagline',
				'priority' => 60,
				'default'  => false,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'site_title_color' => array(
				'title'       => esc_html__( 'Site Title color', 'gutenix' ),
				'section'     => 'title_tagline',
				'priority'    => 65,
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_color' => array(
				'title'       => esc_html__( 'Tagline color', 'gutenix' ),
				'section'     => 'title_tagline',
				'priority'    => 70,
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `General Settings` panel */
			'general_settings' => array(
				'title'    => esc_html__( 'General Settings', 'gutenix' ),
				'priority' => 40,
				'type'     => 'panel',
			),

			/** `Logo & Favicon` section */
			'logo_favicon' => array(
				'title'    => esc_html__( 'Logo &amp; Favicon', 'gutenix' ),
				'priority' => 5,
				'panel'    => 'general_settings',
				'type'     => 'section',
			),

			/** `Page Layout` section */
			'page_layout' => array(
				'title'    => esc_html__( 'Page Layout', 'gutenix' ),
				'priority' => 10,
				'type'     => 'section',
				'panel'    => 'general_settings',
			),
			'container_width' => array(
				'title'       => esc_html__( 'Container width, px', 'gutenix' ),
				'section'     => 'page_layout',
				'priority'    => 5,
				'default'     => 1200,
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 700,
					'max'  => 2000,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'layout_type' => array(
				'title'    => esc_html__( 'Layout', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 10,
				'default'  => 'boxed-content-sidebar',
				'field'    => 'select',
				'choices'  => Gutenix_Utils::get_page_layout_options(),
				'type'     => 'control',
			),
			'layout_type_pages' => array(
				'title'    => esc_html__( 'Layout for Pages', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 15,
				'default'  => '',
				'field'    => 'select',
				'choices'  => array_merge( array( '' => esc_html__( 'Default', 'gutenix' ) ), Gutenix_Utils::get_page_layout_options() ),
				'type'     => 'control',
			),
			'layout_type_blog' => array(
				'title'    => esc_html__( 'Layout for Blog Page & Blog Archives', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 20,
				'default'  => '',
				'field'    => 'select',
				'choices'  => array_merge( array( '' => esc_html__( 'Default', 'gutenix' ) ), Gutenix_Utils::get_page_layout_options() ),
				'type'     => 'control',
			),
			'layout_type_post' => array(
				'title'    => esc_html__( 'Layout for Blog Post', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 25,
				'default'  => '',
				'field'    => 'select',
				'choices'  => array_merge( array( '' => esc_html__( 'Default', 'gutenix' ) ), Gutenix_Utils::get_page_layout_options() ),
				'type'     => 'control',
			),
			'show_page_title' => array(
				'title'    => esc_html__( 'Show page title', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 40,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'content_padding_top' => array(
				'title'       => esc_html__( 'Content Padding Top, px', 'gutenix' ),
				'section'     => 'page_layout',
				'priority'    => 45,
				'default'     => '40',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'content_padding_bottom' => array(
				'title'       => esc_html__( 'Content Padding Bottom, px', 'gutenix' ),
				'section'     => 'page_layout',
				'priority'    => 50,
				'default'     => '70',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `ToTop Button` section */
			'totop_button' => array(
				'title'    => esc_html__( 'ToTop Button', 'gutenix' ),
				'priority' => 20,
				'type'     => 'section',
				'panel'    => 'general_settings',
			),
			'show_totop_button' => array(
				'title'   => esc_html__( 'Show ToTop button', 'gutenix' ),
				'section' => 'totop_button',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'totop_bg_color' => array(
				'title'       => esc_html__( 'Background Color', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),
			'totop_icon_color' => array(
				'title'       => esc_html__( 'Icon Color', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),
			'totop_bg_color_hover' => array(
				'title'       => esc_html__( 'Background Color on Hover', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),
			'totop_icon_color_hover' => array(
				'title'       => esc_html__( 'Icon Color on Hover', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),
			'totop_vertical_padding' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '10',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),
			'totop_horizontal_padding' => array(
				'title'       => esc_html__( 'Horizontal Padding, px', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '10',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),
			'totop_border_radius' => array(
				'title'       => esc_html__( 'Border Radius, px', 'gutenix' ),
				'section'     => 'totop_button',
				'default'     => '4',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_totop_button' => true,
				),
			),

			/** `Mobile Browsers` section */
			'mobile_browsers' => array(
				'title'    => esc_html__( 'Mobile Browsers', 'gutenix' ),
				'priority' => 25,
				'type'     => 'section',
				'panel'    => 'general_settings',
			),
			'address_bar_color' => array(
				'title'       => esc_html__( 'Address Bar Color', 'gutenix' ),
				'description' => esc_html__( 'Specifies the color of address bar and toolbar on mobile browsers.', 'gutenix' ),
				'section'     => 'mobile_browsers',
				'default'     => '#3260B1',
				'field'       => 'hex_color',
				'type'        => 'control',
			),

			/** `Color Scheme` panel */
			'color_scheme' => array(
				'title'       => esc_html__( 'Color Scheme', 'gutenix' ),
				'description' => esc_html__( 'Configure Color Scheme', 'gutenix' ),
				'priority'    => 50,
				'type'        => 'section',
			),
			'primary_color' => array(
				'title'       => esc_html__( 'Primary color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#3260B1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'secondary_color' => array(
				'title'       => esc_html__( 'Secondary color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'primary_text_color' => array(
				'title'       => esc_html__( 'Primary Text color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'secondary_text_color' => array(
				'title'       => esc_html__( 'Secondary Text color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'invert_text_color' => array(
				'title'       => esc_html__( 'Invert Text color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'link_color' => array(
				'title'       => esc_html__( 'Link color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#3260B1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'link_hover_color' => array(
				'title'       => esc_html__( 'Link hover color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'heading_color' => array(
				'title'       => esc_html__( 'Heading color', 'gutenix' ),
				'section'     => 'color_scheme',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Typography Settings` panel */
			'typography' => array(
				'title'       => esc_html__( 'Typography', 'gutenix' ),
				'description' => esc_html__( 'Configure typography settings', 'gutenix' ),
				'priority'    => 55,
				'type'        => 'panel',
			),

			/** `Text Logo` section */
			'logo_typography' => array(
				'title' => esc_html__( 'Text Logo', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'logo_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'logo_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'logo_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => '900',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'logo_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => '26',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'logo_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => '1.2',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'logo_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => - 10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'logo_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'logo_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Tagline` section */
			'tagline_typography' => array(
				'title' => esc_html__( 'Tagline', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'tagline_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => '400',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => '14',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => '1.3',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => - 10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'tagline_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'tagline_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Body text` section */
			'body_typography' => array(
				'title' => esc_html__( 'Body text', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'body_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => '400',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => '20',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => '1.6',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'body_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'body_typography',
				'default'     => 'left',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `H1 Heading` section */
			'h1_typography' => array(
				'title' => esc_html__( 'H1 Heading', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'h1_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => '700',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => '64',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_font_size_mobile' => array(
				'title'       => esc_html__( 'Font Size (tablet, mobile), px', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => '',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => '1.2',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h1_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'h1_typography',
				'default'     => 'inherit',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `H2 Heading` section */
			'h2_typography' => array(
				'title' => esc_html__( 'H2 Heading', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'h2_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => '700',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => '48',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_font_size_mobile' => array(
				'title'       => esc_html__( 'Font Size (tablet, mobile), px', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => '',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => '1.2',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h2_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'h2_typography',
				'default'     => 'inherit',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `H3 Heading` section */
			'h3_typography' => array(
				'title' => esc_html__( 'H3 Heading', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'h3_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => '700',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => '34',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_font_size_mobile' => array(
				'title'       => esc_html__( 'Font Size (tablet, mobile), px', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => '',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => '1.3',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h3_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'h3_typography',
				'default'     => 'inherit',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `H4 Heading` section */
			'h4_typography' => array(
				'title' => esc_html__( 'H4 Heading', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'h4_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => '700',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => '24',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => '1.5',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h4_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'h4_typography',
				'default'     => 'inherit',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `H5 Heading` section */
			'h5_typography' => array(
				'title' => esc_html__( 'H5 Heading', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'h5_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => '700',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => '20',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => '1.6',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h5_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'h5_typography',
				'default'     => 'inherit',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `H6 Heading` section */
			'h6_typography' => array(
				'title' => esc_html__( 'H6 Heading', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'h6_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => '500',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => '16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => '1.6',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'h6_text_align' => array(
				'title'       => esc_html__( 'Text Align', 'gutenix' ),
				'section'     => 'h6_typography',
				'default'     => 'inherit',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_text_aligns(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Input text` section */
			'input_typography' => array(
				'title' => esc_html__( 'Input text', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'input_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'input_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'input_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => '400',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'input_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => '16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'input_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => '1.6',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'input_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'input_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'input_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Button` section */
			'button_typography' => array(
				'title' => esc_html__( 'Button', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'button_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'button_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'button_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => '800',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'button_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => '16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'button_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => '1.5',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'button_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => - 10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'button_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'button_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Header Button` section */
			'header_buttons_typography' => array(
				'title' => esc_html__( 'Header Buttons', 'gutenix' ),
				'panel' => 'typography',
				'type'  => 'section',
			),
			'header_button_font_family' => array(
				'title'       => esc_html__( 'Font Family', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => 'Libre Franklin, sans-serif',
				'field'       => 'fonts',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_button_font_style' => array(
				'title'       => esc_html__( 'Font Style', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => 'normal',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_styles(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_button_font_weight' => array(
				'title'       => esc_html__( 'Font Weight', 'gutenix' ),
				'description' => esc_html__( 'Important: Not all fonts support every font-weight.', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => '800',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_font_weight(),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_button_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => '16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_button_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'gutenix' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => '1.5',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_button_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => - 10,
					'max'  => 10,
					'step' => 0.1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_button_character_set' => array(
				'title'       => esc_html__( 'Character Set', 'gutenix' ),
				'section'     => 'header_buttons_typography',
				'default'     => 'latin',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_character_sets(),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Header` panel */
			'header_options' => array(
				'title'    => esc_html__( 'Header', 'gutenix' ),
				'priority' => 70,
				'type'     => 'panel',
			),

			/** `Top Panel` section */
			'top_panel' => array(
				'title' => esc_html__( 'Top Panel', 'gutenix' ),
				'panel' => 'header_options',
				'type'  => 'section',
			),
			'top_panel_visible' => array(
				'title'   => esc_html__( 'Show top panel', 'gutenix' ),
				'section' => 'top_panel',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'top_panel_container_type' => array(
				'title'      => esc_html__( 'Container type', 'gutenix' ),
				'section'    => 'top_panel',
				'default'    => 'boxed',
				'field'      => 'select',
				'choices'    => array(
					'boxed' => esc_html__( 'Boxed', 'gutenix' ),
					'fluid' => esc_html__( 'Full Width', 'gutenix' ),
				),
				'type'       => 'control',
				'conditions' => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_text' => array(
				'title'       => esc_html__( 'Disclaimer Text', 'gutenix' ),
				'description' => esc_html__( 'HTML formatting support', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => esc_html__( 'Premium WordPress Theme', 'gutenix' ),
				'field'       => 'textarea',
				'type'        => 'control',
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_social_links_visible' => array(
				'title'      => esc_html__( 'Show Social Links', 'gutenix' ),
				'section'    => 'top_panel',
				'default'    => true,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_bg' => array(
				'title'       => esc_html__( 'Background color', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_text_color' => array(
				'title'       => esc_html__( 'Text color', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_link_color' => array(
				'title'       => esc_html__( 'Link color', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_link_hover_color' => array(
				'title'       => esc_html__( 'Link hover color', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_vertical_padding' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => '10',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),
			'top_panel_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'top_panel',
				'default'     => '14',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'top_panel_visible' => true,
				),
			),

			/** `Header Bar` section */
			'header_bar' => array(
				'title' => esc_html__( 'Header Bar', 'gutenix' ),
				'panel' => 'header_options',
				'type'  => 'section',
			),
			'header_layout_type' => array(
				'title'   => esc_html__( 'Layout', 'gutenix' ),
				'section' => 'header_bar',
				'default' => 'style-1',
				'choices' => Gutenix_Utils::get_header_layout_options(),
				'field'   => 'select',
				'type'    => 'control',
			),
			'header_container_type' => array(
				'title'   => esc_html__( 'Container type', 'gutenix' ),
				'section' => 'header_bar',
				'default' => 'boxed',
				'field'   => 'select',
				'choices' => array(
					'boxed' => esc_html__( 'Boxed', 'gutenix' ),
					'fluid' => esc_html__( 'Full Width', 'gutenix' ),
				),
				'type'    => 'control',
			),
			'header_mobile_panel_breakpoint' => array(
				'title'      => esc_html__( 'Mobile Panel Visibility', 'gutenix' ),
				'section'    => 'header_bar',
				'default'    => 'lg',
				'field'      => 'select',
				'choices'    => array(
					''   => esc_html__( 'None', 'gutenix' ),
					'lg' => esc_html__( 'Tablet &amp; Mobile Devices', 'gutenix' ),
					'md' => esc_html__( 'Mobile Devices', 'gutenix' ),
				),
				'type'       => 'control',
				'conditions' => array(
					'header_layout_type!' => Gutenix_Utils::get_header_hamburger_panel_layouts(),
				),
			),
			'header_search_visible' => array(
				'title'   => esc_html__( 'Show Search', 'gutenix' ),
				'section' => 'header_bar',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'header_social_links_visible' => array(
				'title'   => esc_html__( 'Show Social Links', 'gutenix' ),
				'section' => 'header_bar',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'header_bg' => array(
				'title'       => esc_html__( 'Background Color', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_bg_img' => array(
				'title'       => esc_html__( 'Background Image', 'gutenix' ),
				'section'     => 'header_bar',
				'field'       => 'image',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_bg_size' => array(
				'title'       => esc_html__( 'Background Size', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => 'cover',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_size(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'header_bg_img!' => '',
				),
			),
			'header_bg_position' => array(
				'title'       => esc_html__( 'Background Position', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => 'center',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_position(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'header_bg_img!' => '',
				),
			),
			'header_bg_repeat' => array(
				'title'       => esc_html__( 'Background Repeat', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => 'no-repeat',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_repeat(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'header_bg_img!' => '',
				),
			),
			'header_bg_attachment' => array(
				'title'       => esc_html__( 'Background Attachment', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => 'scroll',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_attachment(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'header_bg_img!' => '',
				),
			),
			'header_link_color' => array(
				'title'       => esc_html__( 'Link color', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_link_hover_color' => array(
				'title'       => esc_html__( 'Link hover color', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'header_search_input_color' => array(
				'title'       => esc_html__( 'Search Input color', 'gutenix' ),
				'section'     => 'header_bar',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'header_search_visible' => true,
				),
			),
			'header_vertical_padding' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'header_bar',
				'default'     => '30',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Main Menu` section */
			'main_menu' => array(
				'title' => esc_html__( 'Main Menu', 'gutenix' ),
				'panel' => 'header_options',
				'type'  => 'section',
			),
			'main_menu_hover_style' => array(
				'title'   => esc_html__( 'Hover Style', 'gutenix' ),
				'section' => 'main_menu',
				'default' => 'none',
				'field'   => 'select',
				'choices' => array(
					'none'        => esc_html__( 'None', 'gutenix' ),
					'underline'   => esc_html__( 'Underline', 'gutenix' ),
					'overline'    => esc_html__( 'Overline', 'gutenix' ),
					'double-line' => esc_html__( 'Double Line', 'gutenix' ),
					'framed'      => esc_html__( 'Framed', 'gutenix' ),
				),
				'type'    => 'control',
			),
			'animation_line' => array(
				'title'   => esc_html__( 'Animation', 'gutenix' ),
				'section' => 'main_menu',
				'default' => 'none',
				'field'   => 'select',
				'choices' => array(
					'none'     => esc_html__( 'None', 'gutenix' ),
					'fade'     => esc_html__( 'Fade', 'gutenix' ),
					'slide'    => esc_html__( 'Slide', 'gutenix' ),
					'grow'     => esc_html__( 'Grow', 'gutenix' ),
					'drop-in'  => esc_html__( 'Drop In', 'gutenix' ),
					'drop-out' => esc_html__( 'Drop Out', 'gutenix' ),
				),
				'type'       => 'control',
				'conditions' => array(
					'main_menu_hover_style' => array( 'underline', 'overline', 'double-line' ),
				),
			),
			'animation_framed' => array(
				'title'   => esc_html__( 'Animation', 'gutenix' ),
				'section' => 'main_menu',
				'default' => 'none',
				'field'   => 'select',
				'choices' => array(
					'none'    => esc_html__( 'None', 'gutenix' ),
					'fade'    => esc_html__( 'Fade', 'gutenix' ),
					'grow'    => esc_html__( 'Grow', 'gutenix' ),
					'shrink'  => esc_html__( 'Shrink', 'gutenix' ),
					'draw'    => esc_html__( 'Draw', 'gutenix' ),
					'corners' => esc_html__( 'Corners', 'gutenix' ),
				),
				'type'       => 'control',
				'conditions' => array(
					'main_menu_hover_style' => 'framed',
				),
			),
			'main_menu_link_color' => array(
				'title'       => esc_html__( 'Top Level Link color', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'main_menu_link_hover_color' => array(
				'title'       => esc_html__( 'Top Level Link color on Hover', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'sub_menu_bg' => array(
				'title'       => esc_html__( 'Sub Menu Background color', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'sub_menu_link_color' => array(
				'title'       => esc_html__( 'Sub Menu Link color', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'sub_menu_link_bg' => array(
				'title'       => esc_html__( 'Sub Menu Link Background color', 'gutenix' ),
				'section'     => 'main_menu',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'sub_menu_link_hover_color' => array(
				'title'       => esc_html__( 'Sub Menu Link color on Hover', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '#3260B1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'sub_menu_link_hover_bg' => array(
				'title'       => esc_html__( 'Sub Menu Link Background color on Hover', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '#f6f6f7',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'main_menu_font_size' => array(
				'title'       => esc_html__( 'Top Level Font Size, px', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'sub_menu_font_size' => array(
				'title'       => esc_html__( 'Sub Menu Font Size, px', 'gutenix' ),
				'section'     => 'main_menu',
				'default'     => '16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Vertical Menu` section */
			'vertical_menu' => array(
				'title' => esc_html__( 'Vertical Menu', 'gutenix' ),
				'panel' => 'header_options',
				'type'  => 'section',
			),

			'vertical_menu_link_color' => array(
				'title'       => esc_html__( 'Link color', 'gutenix' ),
				'section'     => 'vertical_menu',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'vertical_menu_link_hover_color' => array(
				'title'       => esc_html__( 'Link color on Hover', 'gutenix' ),
				'section'     => 'vertical_menu',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'vertical_menu_font_size' => array(
				'title'       => esc_html__( 'Top Level Font Size, px', 'gutenix' ),
				'section'     => 'vertical_menu',
				'default'     => '34',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'vertical_sub_menu_font_size' => array(
				'title'       => esc_html__( 'Sub Menu Font Size, px', 'gutenix' ),
				'section'     => 'vertical_menu',
				'default'     => '30',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Header Button 1` section */
			'header_button_1' => array(
				'title' => esc_html__( 'Header Button 1', 'gutenix' ),
				'panel' => 'header_options',
				'type'  => 'section',
			),
			'show_header_btn_1' => array(
				'title'   => esc_html__( 'Show Button 1', 'gutenix' ),
				'section' => 'header_button_1',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'header_btn_text_1' => array(
				'title'      => esc_html__( 'Button Text', 'gutenix' ),
				'section'    => 'header_button_1',
				'default'    => esc_html__( 'Button', 'gutenix' ),
				'field'      => 'text',
				'type'       => 'control',
				'transport'  => 'postMessage',
				'conditions' => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_url_1' => array(
				'title'      => esc_html__( 'Button Url', 'gutenix' ),
				'section'    => 'header_button_1',
				'default'    => '#',
				'field'      => 'url',
				'type'       => 'control',
				'conditions' => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_external_1' => array(
				'title'      => esc_html__( 'Open Link in New Tab', 'gutenix' ),
				'section'    => 'header_button_1',
				'default'    => false,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_bg_1' => array(
				'title'       => esc_html__( 'Background color', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_text_color_1' => array(
				'title'       => esc_html__( 'Text color', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_border_color_1' => array(
				'title'       => esc_html__( 'Border color', 'gutenix' ),
				'section'     => 'header_button_1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_bg_hover_1' => array(
				'title'       => esc_html__( 'Background color on Hover', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_text_color_hover_1' => array(
				'title'       => esc_html__( 'Text color on Hover', 'gutenix' ),
				'section'     => 'header_button_1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_border_color_hover_1' => array(
				'title'       => esc_html__( 'Border color on Hover', 'gutenix' ),
				'section'     => 'header_button_1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_vertical_padding_1' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '6',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_horizontal_padding_1' => array(
				'title'       => esc_html__( 'Horizontal Padding, px', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '20',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_border_width_1' => array(
				'title'       => esc_html__( 'Border Width, px', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),
			'header_btn_border_radius_1' => array(
				'title'       => esc_html__( 'Border Radius, px', 'gutenix' ),
				'section'     => 'header_button_1',
				'default'     => '4',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_1' => true,
				),
			),

			/** `Header Button 2` section */
			'header_button_2' => array(
				'title' => esc_html__( 'Header Button 2', 'gutenix' ),
				'panel' => 'header_options',
				'type'  => 'section',
			),
			'show_header_btn_2' => array(
				'title'   => esc_html__( 'Show Button 2', 'gutenix' ),
				'section' => 'header_button_2',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'header_btn_text_2' => array(
				'title'      => esc_html__( 'Button Text', 'gutenix' ),
				'section'    => 'header_button_2',
				'default'    => esc_html__( 'Button', 'gutenix' ),
				'field'      => 'text',
				'type'       => 'control',
				'transport'  => 'postMessage',
				'conditions' => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_url_2' => array(
				'title'      => esc_html__( 'Button Url', 'gutenix' ),
				'section'    => 'header_button_2',
				'default'    => '#',
				'field'      => 'url',
				'type'       => 'control',
				'conditions' => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_external_2' => array(
				'title'      => esc_html__( 'Open Link in New Tab', 'gutenix' ),
				'section'    => 'header_button_2',
				'default'    => false,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_bg_2' => array(
				'title'       => esc_html__( 'Background color', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '#414756',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_text_color_2' => array(
				'title'       => esc_html__( 'Text color', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '#ffffff',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_border_color_2' => array(
				'title'       => esc_html__( 'Border color', 'gutenix' ),
				'section'     => 'header_button_2',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_bg_hover_2' => array(
				'title'       => esc_html__( 'Background color on Hover', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_text_color_hover_2' => array(
				'title'       => esc_html__( 'Text color on Hover', 'gutenix' ),
				'section'     => 'header_button_2',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_border_color_hover_2' => array(
				'title'       => esc_html__( 'Border color on Hover', 'gutenix' ),
				'section'     => 'header_button_2',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_vertical_padding_2' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '6',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_horizontal_padding_2' => array(
				'title'       => esc_html__( 'Horizontal Padding, px', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '20',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_border_width_2' => array(
				'title'       => esc_html__( 'Border Width, px', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),
			'header_btn_border_radius_2' => array(
				'title'       => esc_html__( 'Border Radius, px', 'gutenix' ),
				'section'     => 'header_button_2',
				'default'     => '4',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'show_header_btn_2' => true,
				),
			),

			/** `Footer` panel */
			'footer_options' => array(
				'title'    => esc_html__( 'Footer', 'gutenix' ),
				'priority' => 75,
				'type'     => 'panel',
			),

			/** `Footer Widgets Area` section */
			'footer_widgets' => array(
				'title' => esc_html__( 'Footer Widgets Area', 'gutenix' ),
				'panel' => 'footer_options',
				'type'  => 'section',
			),
			'footer_widgets_visible' => array(
				'title'   => esc_html__( 'Show Footer Widgets Area', 'gutenix' ),
				'section' => 'footer_widgets',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'footer_widgets_columns' => array(
				'title'      => esc_html__( 'Columns', 'gutenix' ),
				'section'    => 'footer_widgets',
				'default'    => '4',
				'field'      => 'select',
				'choices'    => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
				),
				'type'       => 'control',
				'conditions' => array(
					'footer_widgets_visible' => true,
				),
			),
			'footer_widgets_container_type' => array(
				'title'      => esc_html__( 'Container type', 'gutenix' ),
				'section'    => 'footer_widgets',
				'default'    => 'boxed',
				'field'      => 'select',
				'choices'    => array(
					'boxed' => esc_html__( 'Boxed', 'gutenix' ),
					'fluid' => esc_html__( 'Full Width', 'gutenix' ),
				),
				'type'       => 'control',
				'conditions' => array(
					'footer_widgets_visible' => true,
				),
			),
			'footer_widgets_bg' => array(
				'title'       => esc_html__( 'Background color', 'gutenix' ),
				'section'     => 'footer_widgets',
				'default'     => '#f6f6f7',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'footer_widgets_visible' => true,
				),
			),
			'footer_widgets_vertical_padding' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'footer_widgets',
				'default'     => '70',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'footer_widgets_visible' => true,
				),
			),

			/** `Footer Bar` section */
			'footer_bar' => array(
				'title' => esc_html__( 'Footer Bar', 'gutenix' ),
				'panel' => 'footer_options',
				'type'  => 'section',
			),
			'footer_layout_type' => array(
				'title'   => esc_html__( 'Layout', 'gutenix' ),
				'section' => 'footer_bar',
				'default' => 'style-1',
				'choices' => Gutenix_Utils::get_footer_layout_options(),
				'field'   => 'select',
				'type'    => 'control',
			),
			'footer_container_type' => array(
				'title'   => esc_html__( 'Container type', 'gutenix' ),
				'section' => 'footer_bar',
				'default' => 'boxed',
				'field'   => 'select',
				'choices' => array(
					'boxed' => esc_html__( 'Boxed', 'gutenix' ),
					'fluid' => esc_html__( 'Full Width', 'gutenix' ),
				),
				'type'    => 'control',
			),
			'footer_logo_visible' => array(
				'title'   => esc_html__( 'Show Footer Logo', 'gutenix' ),
				'section' => 'footer_bar',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'footer_logo' => array(
				'title'        => esc_html__( 'Footer Logo', 'gutenix' ),
				'section'      => 'footer_bar',
				'field'        => 'cropped_image',
				'cropped_args' => Gutenix_Utils::get_footer_logo_args(),
				'labels'       => Gutenix_Utils::get_custom_logo_labels(),
				'type'         => 'control',
				'conditions'   => array(
					'footer_logo_visible' => true,
				),
			),
			'footer_copyright' => array(
				'title'   => esc_html__( 'Copyright text', 'gutenix' ),
				'section' => 'footer_bar',
				'default' => Gutenix_Utils::get_default_footer_copyright(),
				'field'   => 'textarea',
				'type'    => 'control',
			),
			'footer_menu_visible' => array(
				'title'   => esc_html__( 'Show Footer Menu', 'gutenix' ),
				'section' => 'footer_bar',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'footer_social_links_visible' => array(
				'title'   => esc_html__( 'Show Social Links', 'gutenix' ),
				'section' => 'footer_bar',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'footer_bg' => array(
				'title'       => esc_html__( 'Background Color', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '#f6f6f7',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_bg_img' => array(
				'title'       => esc_html__( 'Background Image', 'gutenix' ),
				'section'     => 'footer_bar',
				'field'       => 'image',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_bg_size' => array(
				'title'       => esc_html__( 'Background Size', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => 'cover',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_size(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'footer_bg_img!' => '',
				),
			),
			'footer_bg_position' => array(
				'title'       => esc_html__( 'Background Position', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => 'center',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_position(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'footer_bg_img!' => '',
				),
			),
			'footer_bg_repeat' => array(
				'title'       => esc_html__( 'Background Repeat', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => 'no-repeat',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_repeat(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'footer_bg_img!' => '',
				),
			),
			'footer_bg_attachment' => array(
				'title'       => esc_html__( 'Background Attachment', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => 'scroll',
				'field'       => 'select',
				'choices'     => Gutenix_Utils::get_bg_attachment(),
				'type'        => 'control',
				'dynamic_css' => true,
				'conditions'  => array(
					'footer_bg_img!' => '',
				),
			),
			'footer_text_color' => array(
				'title'       => esc_html__( 'Text color', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_link_color' => array(
				'title'       => esc_html__( 'Link color', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '#a0a3aa',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_link_hover_color' => array(
				'title'       => esc_html__( 'Link hover color', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '#3260b1',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_vertical_padding' => array(
				'title'       => esc_html__( 'Vertical Padding, px', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '25',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_border_top_width' => array(
				'title'       => esc_html__( 'Border Top Width, px', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_border_top_color' => array(
				'title'       => esc_html__( 'Border Top Color', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '#e8e9eb',
				'field'       => 'hex_color',
				'type'        => 'control',
				'dynamic_css' => true,
			),
			'footer_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'gutenix' ),
				'section'     => 'footer_bar',
				'default'     => '14',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'        => 'control',
				'dynamic_css' => true,
			),

			/** `Blog Settings` panel */
			'blog_settings' => array(
				'title'    => esc_html__( 'Blog Settings', 'gutenix' ),
				'priority' => 80,
				'type'     => 'panel',
			),

			/** `Blog` section */
			'blog' => array(
				'title'    => esc_html__( 'Blog', 'gutenix' ),
				'panel'    => 'blog_settings',
				'priority' => 5,
				'type'     => 'section',
			),
			'blog_sticky_type' => array(
				'title'    => esc_html__( 'Sticky label type', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 10,
				'default'  => 'icon',
				'field'    => 'select',
				'choices'  => array(
					'label' => esc_html__( 'Text Label', 'gutenix' ),
					'icon'  => esc_html__( 'Font Icon', 'gutenix' ),
					'both'  => esc_html__( 'Text with Icon', 'gutenix' ),
				),
				'type'     => 'control',
			),
			'blog_sticky_label' => array(
				'title'       => esc_html__( 'Featured Post Label', 'gutenix' ),
				'description' => esc_html__( 'Label for sticky post', 'gutenix' ),
				'section'     => 'blog',
				'priority'    => 15,
				'default'     => esc_html__( 'Featured', 'gutenix' ),
				'field'       => 'text',
				'type'        => 'control',
				'transport'   => 'postMessage',
				'conditions'  => array(
					'blog_sticky_type' => array( 'label', 'both' ),
				),
			),
			'blog_post_author' => array(
				'title'    => esc_html__( 'Show post author', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 20,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_post_publish_date' => array(
				'title'    => esc_html__( 'Show publish date', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 25,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_post_categories' => array(
				'title'    => esc_html__( 'Show categories', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 30,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_post_tags' => array(
				'title'    => esc_html__( 'Show tags', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 35,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_post_comments' => array(
				'title'    => esc_html__( 'Show comments', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 40,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_post_excerpt' => array(
				'title'    => esc_html__( 'Show excerpt', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 45,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_post_excerpt_words_count' => array(
				'title'       => esc_html__( 'Excerpt Words Count', 'gutenix' ),
				'section'     => 'blog',
				'priority'    => 50,
				'default'     => '20',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'conditions'  => array(
					'blog_post_excerpt' => true,
				),
			),
			'blog_read_more' => array(
				'title'    => esc_html__( 'Show read more button', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 55,
				'default'  => true,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			'blog_read_more_text' => array(
				'title'      => esc_html__( 'Read more button text', 'gutenix' ),
				'section'    => 'blog',
				'priority'   => 60,
				'default'    => esc_html__( 'Learn More', 'gutenix' ),
				'field'      => 'text',
				'type'       => 'control',
				'transport'  => 'postMessage',
				'conditions' => array(
					'blog_read_more' => true,
				),
			),
			'blog_navigation_type' => array(
				'title'    => esc_html__( 'Navigation type', 'gutenix' ),
				'section'  => 'blog',
				'priority' => 65,
				'default'  => 'pagination',
				'field'    => 'select',
				'choices'  => array(
					'navigation' => esc_html__( 'Navigation', 'gutenix' ),
					'pagination' => esc_html__( 'Pagination', 'gutenix' ),
				),
				'type'     => 'control',
			),

			/** `Post` section */
			'blog_post' => array(
				'title'           => esc_html__( 'Post', 'gutenix' ),
				'panel'           => 'blog_settings',
				'priority'        => 10,
				'type'            => 'section',
				'active_callback' => 'callback_single',
			),
			'single_post_author' => array(
				'title'   => esc_html__( 'Show post author', 'gutenix' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_publish_date' => array(
				'title'   => esc_html__( 'Show publish date', 'gutenix' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_categories' => array(
				'title'   => esc_html__( 'Show categories', 'gutenix' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_tags' => array(
				'title'   => esc_html__( 'Show tags', 'gutenix' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_comments' => array(
				'title'   => esc_html__( 'Show comments', 'gutenix' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_author_block' => array(
				'title'   => esc_html__( 'Enable the author block after each post', 'gutenix' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),

			/** `Related Posts` section */
			'related_posts' => array(
				'title'           => esc_html__( 'Related posts block', 'gutenix' ),
				'panel'           => 'blog_settings',
				'priority'        => 15,
				'type'            => 'section',
				'active_callback' => 'callback_single',
			),
			'related_posts_visible' => array(
				'title'   => esc_html__( 'Show related posts block', 'gutenix' ),
				'section' => 'related_posts',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'related_posts_block_title' => array(
				'title'      => esc_html__( 'Related posts block title', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => esc_html__( 'Related posts', 'gutenix' ),
				'field'      => 'text',
				'type'       => 'control',
				'transport'  => 'postMessage',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_count' => array(
				'title'       => esc_html__( 'Number of post', 'gutenix' ),
				'section'     => 'related_posts',
				'default'     => '2',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1,
					'max'  => 12,
					'step' => 1,
				),
				'type'        => 'control',
				'conditions'  => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_grid' => array(
				'title'   => esc_html__( 'Layout', 'gutenix' ),
				'section' => 'related_posts',
				'default' => '2',
				'field'   => 'select',
				'choices' => array(
					'2' => esc_html__( '2 columns', 'gutenix' ),
					'3' => esc_html__( '3 columns', 'gutenix' ),
					'4' => esc_html__( '4 columns', 'gutenix' ),
				),
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_image' => array(
				'title'      => esc_html__( 'Show post image', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => true,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_author' => array(
				'title'      => esc_html__( 'Show post author', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => true,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_publish_date' => array(
				'title'      => esc_html__( 'Show post publish date', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => true,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_categories' => array(
				'title'      => esc_html__( 'Show categories', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => true,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_tags' => array(
				'title'      => esc_html__( 'Show tags', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => false,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_comments' => array(
				'title'      => esc_html__( 'Show comments', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => true,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_excerpt' => array(
				'title'      => esc_html__( 'Show excerpt', 'gutenix' ),
				'section'    => 'related_posts',
				'default'    => false,
				'field'      => 'checkbox',
				'type'       => 'control',
				'conditions' => array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_excerpt_words_count' => array(
				'title'       => esc_html__( 'Excerpt Words Count', 'gutenix' ),
				'section'     => 'related_posts',
				'default'     => '20',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1,
					'max'  => 100,
					'step' => 1,
				),
				'type'        => 'control',
				'conditions'  => array(
					'related_posts_visible' => true,
					'related_posts_excerpt' => true,
				),
			),
		),
	) );
}

/**
 * Return array of arguments for dynamic CSS module
 *
 * @since  1.0.0
 * @return array
 */
function gutenix_get_dynamic_css_options() {
	return apply_filters( 'gutenix_get_dynamic_css_options', array(
		'prefix'         => 'gutenix',
		'type'           => 'theme_mod',
		'options_cb'     => 'get_theme_mods',
		'parent_handles' => array(
			'css' => 'gutenix-theme-style',
			'js'  => 'gutenix-theme-script',
		),
		'css_files' => array(
			get_theme_file_path( 'assets/css/dynamic/dynamic.css' ),
			get_theme_file_path( 'assets/css/dynamic/site/post.css' ),
			get_theme_file_path( 'assets/css/dynamic/site/buttons.css' ),
			get_theme_file_path( 'assets/css/dynamic/site/widgets.css' ),
			get_theme_file_path( 'assets/css/dynamic/site/header.css' ),
			get_theme_file_path( 'assets/css/dynamic/site/footer.css' ),
			get_theme_file_path( 'assets/css/dynamic/site/menus.css' ),
		),
	) );
}

/**
 * Change native customize control (based on WordPress core).
 *
 * @since 1.0.0
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function gutenix_customize_register( $wp_customize ) {
	$wp_customize->get_control( 'custom_logo' )->section       = 'gutenix_logo_favicon';
	$wp_customize->get_control( 'site_icon' )->section         = 'gutenix_logo_favicon';
	$wp_customize->get_control( 'background_color' )->section  = 'background_image';
	$wp_customize->get_section( 'background_image' )->priority = 45;
	$wp_customize->get_section( 'background_image' )->title    = esc_html__( 'Body Background', 'gutenix' );

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) && apply_filters( 'gutenix_use_customize_selective_refresh', true ) ) {

		$partial = gutenix_get_selective_refresh_partials();

		foreach ( $partial as $id => $args ) {

			if ( isset( $args['settings'] ) ) {

				foreach ( (array) $args['settings'] as $setting ) {
					$wp_customize->get_setting( $setting )->transport = 'postMessage';
				}

			} else {
				$wp_customize->get_setting( $id )->transport = 'postMessage';
			}

			$wp_customize->selective_refresh->add_partial( $id, $args );
		}
	}
}
add_action( 'customize_register', 'gutenix_customize_register', 20 );

/**
 * Get customize selective refresh partials.
 *
 * @since  1.0.0
 * @return array
 */
function gutenix_get_selective_refresh_partials() {
	return apply_filters( 'gutenix_get_selective_refresh_partials', array(
		'dynamic_css' => array(
			'selector'        => '#gutenix-theme-style-inline-css',
			'settings'        => gutenix_get_dynamic_css_settings_list(),
			'render_callback' => array( gutenix_theme()->dynamic_css, 'get_inline_css' ),
		),
		'fonts_loader' => array(
			'selector'            => '#cx-google-fonts-gutenix-css',
			'settings'            => gutenix_get_fonts_settings_list(),
			'render_callback'     => 'gutenix_customize_partial_fonts_loader',
			'container_inclusive' => true,
		),
		'custom_logo' => array(
			'selector'            => '.site-logo',
			'render_callback'     => 'gutenix_header_logo',
			'container_inclusive' => true,
		),
		'show_tagline' => array(
			'selector'            => '.site-description',
			'render_callback'     => 'gutenix_site_description',
			'container_inclusive' => true,
		),
		'blog_sticky_type' => array(
			'selector'            => '.sticky.post .sticky-label',
			'render_callback'     => 'gutenix_get_sticky_label',
			'container_inclusive' => true,
		),
		'posts_list' => array(
			'selector' => '.blog .site-main, .archive .site-main',
			'settings' => array(
				'blog_post_author',
				'blog_post_publish_date',
				'blog_post_categories',
				'blog_post_tags',
				'blog_post_comments',
				'blog_post_excerpt',
				'blog_post_excerpt_words_count',
				'blog_read_more',
				'blog_navigation_type',
			),
			'render_callback' => 'gutenix_customize_partial_posts_list',
		),
		'single_post' => array(
			'selector' => '.single-post .post.hentry',
			'settings' => array(
				'single_post_author',
				'single_post_publish_date',
				'single_post_categories',
				'single_post_tags',
				'single_post_comments',
			),
			'render_callback'     => 'gutenix_customize_partial_single_post',
			'container_inclusive' => true,
		),
		'single_author_block' => array(
			'selector'        => '.post-author-bio-customize-partial',
			'render_callback' => 'gutenix_customize_partial_author_bio',
		),
		'single_related_posts' => array(
			'selector' => '.related-posts-customize-partial',
			'settings' => array(
				'related_posts_visible',
				'related_posts_count',
				'related_posts_grid',
				'related_posts_image',
				'related_posts_author',
				'related_posts_publish_date',
				'related_posts_categories',
				'related_posts_tags',
				'related_posts_comments',
				'related_posts_excerpt',
				'related_posts_excerpt_words_count',
			),
			'render_callback' => 'gutenix_related_posts',
		),
		'top_panel' => array(
			'selector' => '.top-panel',
			'settings' => array(
				'top_panel_visible',
				'top_panel_container_type',
				'top_panel_text',
				'top_panel_social_links_visible',
			),
			'render_callback'     => 'gutenix_top_panel_markup',
			'container_inclusive' => true,
		),
		'header_bar' => array(
			'selector' => '.header-bar',
			'settings' => array(
				'header_layout_type',
				'header_container_type',
				'header_mobile_panel_breakpoint',
				'header_search_visible',
				'header_social_links_visible',
				'main_menu_hover_style',
				'animation_line',
				'animation_framed',
			),
			'render_callback'     => 'gutenix_header_bar_markup',
			'container_inclusive' => true,
		),
		'header_buttons' => array(
			'selector' => '.header-buttons',
			'settings' => array(
				'show_header_btn_1',
				'header_btn_url_1',
				'header_btn_external_1',
				'show_header_btn_2',
				'header_btn_url_2',
				'header_btn_external_2',
			),
			'render_callback'     => 'gutenix_header_buttons',
			'container_inclusive' => true,
		),
		'footer_widgets_area' => array(
			'selector' => '.footer-area-wrapper',
			'settings' => array(
				'footer_widgets_visible',
				'footer_widgets_columns',
				'footer_widgets_container_type',
			),
			'render_callback'     => 'gutenix_footer_widgets_area_markup',
			'container_inclusive' => true,
		),
		'footer_bar' => array(
			'selector' => '.footer-bar',
			'settings' => array(
				'footer_layout_type',
				'footer_container_type',
				'footer_logo_visible',
				'footer_menu_visible',
				'footer_social_links_visible',
			),
			'render_callback'     => 'gutenix_footer_bar_markup',
			'container_inclusive' => true,
		),
		'footer_logo' => array(
			'selector'            => '.footer-logo',
			'render_callback'     => 'gutenix_footer_logo',
			'container_inclusive' => true,
		),
		'footer_copyright' => array(
			'selector'            => '.footer-copyright',
			'render_callback'     => 'gutenix_footer_copyright',
			'container_inclusive' => true,
		),
	) );
}

/**
 * Render the posts list for the selective refresh partial.
 *
 * @since  1.0.0
 * @return void
 */
function gutenix_customize_partial_posts_list () {

	if ( have_posts() ) :

		get_template_part( 'template-parts/posts-loop' );

	else :

		get_template_part( 'template-parts/content', 'none' );

	endif;
}

/**
 * Render the single post for the selective refresh partial.
 *
 * @since  1.0.0
 * @return void
 */
function gutenix_customize_partial_single_post () {

	while ( have_posts() ) : the_post();

	get_template_part( 'template-parts/content-single', get_post_type() );

	endwhile;
}

/**
 * Render the author bio block for the selective refresh partial.
 *
 * @since  1.0.0
 * @return void
 */
function gutenix_customize_partial_author_bio() {

	while ( have_posts() ) : the_post();

	gutenix_post_author_bio();

	endwhile;
}

/**
 * Render the fonts link for the selective refresh partial.
 *
 * @since  1.0.0
 * @return void
 */
function gutenix_customize_partial_fonts_loader() {
    
    wp_enqueue_style( 'cx-google-fonts-gutenix-css', gutenix_theme()->fonts_manager->get_fonts_url() );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 *
 * @since 1.0.0
 */
function gutenix_customize_preview_js() {
	wp_enqueue_script( 'gutenix-theme-customizer', get_theme_file_uri('assets/js/customizer.js' ), array( 'customize-preview' ), gutenix_theme()->version, true );
}

add_action( 'customize_preview_init', 'gutenix_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 *
 * @since 1.0.0
 */
function gutenix_customize_controls_assets() {
	wp_enqueue_style( 'gutenix-theme-customizer', get_theme_file_uri('assets/css/customizer.min.css' ), array(), gutenix_theme()->version );

	wp_enqueue_script( 'gutenix-theme-customizer-controls', get_theme_file_uri('assets/js/customizer-controls.js' ), array( 'customize-controls' ), gutenix_theme()->version, true );

	wp_localize_script( 'gutenix-theme-customizer-controls', 'gutenixControlsConditions', gutenix_get_customize_controls_conditions() );
}

add_action( 'customize_controls_enqueue_scripts', 'gutenix_customize_controls_assets' );

/**
 * Get customize controls conditions.
 *
 * @since  1.0.0
 * @return array
 */
function gutenix_get_customize_controls_conditions() {

	$customize_options = gutenix_get_customizer_options();
	$controls_args     = $customize_options['options'];

	$results = array();

	foreach ( $controls_args as $control => $args ) {
		if ( isset( $args['conditions'] ) ) {
			$results[ $control ] = $args['conditions'];
		}
	}

	return $results;
}

/**
 * Get dynamic css customize settings list.
 *
 * @since  1.0.0
 * @return array
 */
function gutenix_get_dynamic_css_settings_list() {

	$customize_options = gutenix_get_customizer_options();
	$controls_args     = $customize_options['options'];

	$results = array();

	foreach ( $controls_args as $control => $args ) {
		if ( isset( $args['dynamic_css'] ) && true === $args['dynamic_css'] ) {
			$results[] = $control;
		}
	}

	return $results;
}

/**
 * Get fonts customize settings list.
 *
 * @since  1.0.0
 * @return array
 */
function gutenix_get_fonts_settings_list() {

	$customize_options = gutenix_get_customizer_options();
	$controls_args     = $customize_options['options'];

	$results = array();

	$pairs = array( '_font_style', '_font_weight', '_character_set' );

	foreach ( $controls_args as $control => $args ) {
		if ( ! isset( $args['field'] ) || 'fonts' !== $args['field'] ) {
			continue;
		}

		$results[] = $control;

		$opt_key = str_replace( '_font_family', '', $control );

		foreach ( $pairs as $opt_mod ) {
			$results[] = $opt_key . $opt_mod;
		}

	}

	return $results;
}