<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Gutenix
 */

/**
 * Has sidebar.
 *
 * @since  1.0.0
 * @return bool
 */
function gutenix_has_sidebar() {
	$check = false;

	$layout_type = gutenix_theme()->customizer->get_value( 'layout_type' );

	if ( in_array( $layout_type, array( 'boxed-content-sidebar', 'boxed-sidebar-content' ) ) ) {
		$check = true;
	}

	return $check;
}

/**
 * Check if top panel visible or not
 *
 * @since  1.0.0
 * @return bool
 */
function gutenix_is_top_panel_visible() {
	$is_visible = false;

	if ( ! gutenix_theme()->customizer->get_value( 'top_panel_visible' ) ) {
		return $is_visible;
	}

	$message        = gutenix_theme()->customizer->get_value( 'top_panel_text' );
	$social_visible = gutenix_theme()->customizer->get_value( 'top_panel_social_links_visible' );

	$conditions = apply_filters( 'gutenix_top_panel_visible_conditions', array( $message, $social_visible ), $message, $social_visible );

	foreach ( $conditions as $condition ) {

		if ( ! empty( $condition ) ) {
			$is_visible = true;
		}
	}

	return $is_visible;
}

/**
 * Get breakpoint when mobile panel visible.
 *
 * @since  1.0.0
 * @return string
 */
function gutenix_get_mobile_panel_breakpoint() {
	$breakpoint      = gutenix_theme()->customizer->get_value( 'header_mobile_panel_breakpoint' );
	$header_layout   = gutenix_theme()->customizer->get_value( 'header_layout_type' );
	$exclude_layouts = Gutenix_Utils::get_header_hamburger_panel_layouts();

	if ( in_array( $header_layout, $exclude_layouts ) ) {
		return '';
	}

	return $breakpoint;
}

/**
 * Get post template part slug.
 *
 * @since  1.0.0
 * @return string
 */
function gutenix_get_post_template_part_slug() {
	return apply_filters( 'gutenix_post_template_part_slug', 'template-parts/content' );
}
