<?php
/**
 * WooCommerce customizer options
 *
 * @package Gutenix
 */

if ( ! function_exists( 'gutenix_set_wc_dynamic_css_options' ) ) {

	/**
	 * Add dynamic WooCommerce styles
	 *
	 * @param $options
	 *
	 * @return mixed
	 */
	function gutenix_set_wc_dynamic_css_options( $options ) {

		array_push( $options['css_files'], get_theme_file_path( 'inc/modules/woo/assets/css/dynamic/woo-module-dynamic.css' ) );

		return $options;

	}

}
add_filter( 'gutenix_get_dynamic_css_options', 'gutenix_set_wc_dynamic_css_options' );

if ( ! function_exists( 'gutenix_set_wc_customizer_options' ) ) {
	/**
	 * Add WooCommerce customizer options
	 *
	 * @param  array $options Options list
	 *
	 * @return array
	 */
	function gutenix_set_wc_customizer_options( $options ) {

		$new_options = array(
			'layout_type_shop'    => array(
				'title'    => esc_html__( 'Layout for Shop Page & Shop Archives', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 30,
				'default'  => '',
				'field'    => 'select',
				'choices'  => array_merge( array( '' => esc_html__( 'Default', 'gutenix' ) ), Gutenix_Utils::get_page_layout_options() ),
				'type'     => 'control',
			),
			'layout_type_product' => array(
				'title'    => esc_html__( 'Layout for Single Product', 'gutenix' ),
				'section'  => 'page_layout',
				'priority' => 35,
				'default'  => '',
				'field'    => 'select',
				'choices'  => array_merge( array( '' => esc_html__( 'Default', 'gutenix' ) ), Gutenix_Utils::get_page_layout_options() ),
				'type'     => 'control',
			),

			'woocommerce_accent_color' => array(
				'title'    => esc_html__( 'WooCommerce Accent color', 'gutenix' ),
				'section'  => 'color_scheme',
				'priority' => 30,
				'default'  => '#27d18b',
				'field'    => 'hex_color',
				'type'     => 'control',
			),
		);

		$options['options'] = array_merge( $new_options, $options['options'] );

		return $options;

	}

	add_filter( 'gutenix_get_customizer_options', 'gutenix_set_wc_customizer_options' );
}


if ( ! function_exists( 'gutenix_wc_set_specific_layout_type' ) ) {

	/**
	 * Set specific layout type.
	 *
	 * @since  1.0.0
	 *
	 * @param  string $value Default value.
	 *
	 * @return string
	 */
	function gutenix_wc_set_specific_layout_type( $value = '' ) {

		if( is_cart() || is_checkout() ){
			return 'boxed-full-width';
		}

		if ( is_shop() || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) {
			$shop_layout = gutenix_theme()->customizer->get_value( 'layout_type_shop' );

			if ( ! empty( $shop_layout ) ) {
				return $shop_layout;
			}
		}

		if ( is_singular( 'product' ) ) {
			$product_layout = gutenix_theme()->customizer->get_value( 'layout_type_product' );

			if ( ! empty( $product_layout ) ) {
				return $product_layout;
			}
		}

		return $value;
	}

	// Set specific page layout.
	add_filter( 'theme_mod_layout_type', 'gutenix_wc_set_specific_layout_type' );
}

